"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const error_1 = require("../error");
class BasicHost {
    constructor() {
        this.httpRegex = /(https?:\/\/)(?:[^:@]+:[^:@]+@)?([^\/:]+)(?:\/)([^\/:]+)(?:\/)([^\/:\n]+)/;
        this.gitRegex = /(git@)([^\/:]+)(?::)(?:\d+\/)?([^\/:]+)(?:\/)([^\/:\n]+)/;
    }
    parse(configInfo) {
        var _a;
        const matches = (_a = this.httpRegex.exec(configInfo.remoteUrl)) !== null && _a !== void 0 ? _a : this.gitRegex.exec(configInfo.remoteUrl);
        if (!matches) {
            throw new error_1.GitUrlError(`Can't parse ${configInfo.remoteUrl} with the rule of ${this.constructor.name}.`);
        }
        const schema = matches[1];
        let isHttp = false;
        if (schema.startsWith("http://")) {
            isHttp = true;
        }
        let repoName = matches[4];
        if (repoName.endsWith(".git")) {
            repoName = repoName.substring(0, repoName.lastIndexOf(".git"));
        }
        let hostName = matches[2];
        const index = hostName.indexOf("@");
        if (index !== -1) {
            hostName = hostName.substring(index + 1);
        }
        const gitInfo = {
            hostName: hostName,
            repoName: repoName,
            ref: Object.assign(Object.assign({}, configInfo.ref), { value: encodeURIComponent(configInfo.ref.value) }),
            userName: matches[3],
            section: configInfo.section,
            metadata: { isHttp: isHttp },
        };
        if (configInfo.relativeFilePath) {
            let parts = configInfo.relativeFilePath.split("/");
            parts = parts.map(p => encodeURIComponent(p));
            gitInfo.relativeFilePath = parts.join("/");
        }
        return gitInfo;
    }
    assemble(info) {
        return this.assembleLink(info);
    }
    assembleLink(info) {
        let prefix = "https://";
        if (info.metadata && info.metadata["isHttp"]) {
            prefix = "http://";
        }
        return `${prefix}${info.hostName}/${info.userName}/${info.repoName}/${this.separateFolder}/${info.ref.value}/${info.relativeFilePath}`;
    }
}
exports.default = BasicHost;
//# sourceMappingURL=basicHost.js.map