"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const basicHost_1 = __importDefault(require("./basicHost"));
class DevOps extends basicHost_1.default {
    get separateFolder() {
        return undefined;
    }
    get name() {
        return "DevOps";
    }
    match(url) {
        return DevOps.urlRegex.test(url);
    }
    parse(configInfo) {
        const gitInfo = {
            repoName: configInfo.remoteUrl,
            ref: configInfo.ref,
            userName: "",
            section: configInfo.section,
        };
        if (configInfo.relativeFilePath) {
            let parts = configInfo.relativeFilePath.split("/");
            parts = parts.map(p => encodeURIComponent(p));
            gitInfo.relativeFilePath = parts.join("/");
        }
        return gitInfo;
    }
    assemble(info) {
        const baseUrl = info.repoName.replace(DevOps.urlRegex, "https://dev.azure.com/$1/_git/$2");
        const path = encodeURIComponent(`/${info.relativeFilePath}`);
        let version;
        switch (info.ref.type) {
            case "branch":
                version = `GB${info.ref.value}`;
                break;
            case "commit":
                version = `GC${info.ref.value}`;
                break;
        }
        let url = `${baseUrl}?path=${path}&version=${version}&_a=contents`;
        if (info.section && info.section.startLine && info.section.endLine) {
            url += `&lineStyle=plain&line=${info.section.startLine}&lineEnd=${info.section.endLine}`;
            if (info.section.startColumn && info.section.endColumn) {
                url += `&lineStartColumn=${info.section.startColumn}&lineEndColumn=${info.section.endColumn}`;
            }
            else {
                url += "&lineStartColumn=1&lineEndColumn=1";
            }
        }
        return url;
    }
}
exports.default = DevOps;
/**
 * The regular expression to match the DevOps Git URL.
 * @example https://my-tenant@dev.azure.com/my-org/my-project/_git/my-repo
 * @example https://dev.azure.com/my-org/my-project/_git/my-repo
 * @example my-tenant@ssh.dev.azure.com:22/my-org/my-project/my-repo
 */
DevOps.urlRegex = /(?:https:\/\/)?(?:[\w-]+@)?(?:ssh.)?dev\.azure\.com(?::[v\d]+)?\/([^\/]+\/[^\/]+)\/(?:_git\/)?([^/]+)/i;
//# sourceMappingURL=devops.js.map