"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const basicHost_1 = __importDefault(require("./basicHost"));
class Vsts extends basicHost_1.default {
    get separateFolder() {
        return undefined;
    }
    get name() {
        return "VSTS";
    }
    match(url) {
        return Vsts.urlRegex.test(url);
    }
    parse(configInfo) {
        const gitInfo = {
            repoName: configInfo.remoteUrl,
            ref: configInfo.ref,
            userName: "",
            section: configInfo.section,
        };
        if (configInfo.relativeFilePath) {
            let parts = configInfo.relativeFilePath.split("/");
            parts = parts.map(p => encodeURIComponent(p));
            gitInfo.relativeFilePath = parts.join("/");
        }
        return gitInfo;
    }
    assemble(info) {
        const baseUrl = info.repoName.replace(Vsts.urlRegex, "https://$1.visualstudio.com/$2/_git/$3");
        const path = encodeURIComponent(`/${info.relativeFilePath}`);
        let version;
        switch (info.ref.type) {
            case "branch":
                version = `GB${info.ref.value}`;
                break;
            case "commit":
                version = `GC${info.ref.value}`;
                break;
        }
        let url = `${baseUrl}?path=${path}&version=${version}&_a=contents`;
        if (info.section && info.section.startLine && info.section.endLine) {
            url += `&lineStyle=plain&line=${info.section.startLine}&lineEnd=${info.section.endLine}`;
            if (info.section.startColumn && info.section.endColumn) {
                url += `&lineStartColumn=${info.section.startColumn}&lineEndColumn=${info.section.endColumn}`;
            }
            else {
                url += "&lineStartColumn=1&lineEndColumn=1";
            }
        }
        return url;
    }
}
exports.default = Vsts;
/**
 * The regular expression to match the VSTS Git URL.
 * @example https://my-tenant.visualstudio.com/DefaultCollection/MyCollection/_git/my-repo
 * @example ssh://my-tenant@my-tenant.visualstudio.com:22/DefaultCollection/MyCollection/_ssh/my-repo
 */
Vsts.urlRegex = /(?:https:\/\/|ssh:\/\/)([\w-]+)@?.*\.visualstudio\.com(?:\:\d+)?\/(.+)\/(?:_git|_ssh)\/([^/]+)/i;
//# sourceMappingURL=vsts.js.map