"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = __importStar(require("path"));
const fs = __importStar(require("fs-extra"));
const hostBuilder_1 = require("./host/hostBuilder");
const helper_1 = __importDefault(require("./helper"));
const error_1 = require("./error");
const result_1 = require("./result");
class GitUrls {
    static getUrls(filePath, section, hostType) {
        return __awaiter(this, void 0, void 0, function* () {
            const repoRoot = yield helper_1.default.getRepoRoot(filePath);
            if (!repoRoot) {
                throw new error_1.GitUrlError(`Can't find repo root for ${filePath}.`);
            }
            const configMap = yield this.parseConfigAsync(repoRoot);
            const results = new Map();
            for (const [key, configInfo] of configMap) {
                configInfo.relativeFilePath = helper_1.default.normalize(path.relative(repoRoot, filePath));
                if (section) {
                    configInfo.section = section;
                }
                const result = yield this.getUrl(configInfo, hostType);
                results.set(key, result);
            }
            return results;
        });
    }
    static getUrl(configInfo, hostType) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const host = hostBuilder_1.hostBuilder.create(configInfo, hostType);
                const gitInfo = host.parse(configInfo);
                const result = {
                    name: configInfo.remoteName,
                    url: host.assemble(gitInfo),
                };
                return (0, result_1.ok)(result);
            }
            catch (error) {
                if (error instanceof error_1.GitUrlError) {
                    return (0, result_1.err)(error);
                }
                throw error;
            }
        });
    }
    static parseConfigAsync(repoRoot) {
        return __awaiter(this, void 0, void 0, function* () {
            const configPath = path.join(repoRoot, ".git/config");
            const headPath = path.join(repoRoot, ".git/HEAD");
            const existConfig = yield fs.pathExists(configPath);
            const existHead = yield fs.pathExists(headPath);
            if (!existConfig || !existHead) {
                throw new error_1.GitUrlError(`No git config files found in ${repoRoot}.`);
            }
            const configContent = yield fs.readFile(configPath, "utf8");
            const headContent = yield fs.readFile(headPath, "utf8");
            const remoteMap = this.parseRemoteUrl(configContent);
            const ref = this.parseRef(headContent);
            if (!remoteMap) {
                throw new error_1.GitUrlError(`Can't get remote name & url from ${configPath}.`);
            }
            const configMap = new Map();
            for (const [remoteName, remoteUrl] of remoteMap) {
                const info = {
                    remoteName,
                    remoteUrl,
                    ref,
                };
                configMap.set(remoteName, info);
            }
            return configMap;
        });
    }
    static parseRemoteUrl(content) {
        const regex = /\n\[remote \"(.+)\"\]\s+url\s*=\s*(.+)\n/gi;
        const result = new Map();
        let matches = regex.exec(content);
        while (matches !== null) {
            if (matches.index === regex.lastIndex) {
                regex.lastIndex++;
            }
            result.set(matches[1], matches[2]);
            matches = regex.exec(content);
        }
        if (result.size > 0) {
            return result;
        }
        return null;
    }
    static parseRef(content) {
        const branchRegex = /ref:\s+refs\/heads\/(\S+)/;
        const branchMatches = branchRegex.exec(content);
        if (branchMatches) {
            return { type: "branch", value: branchMatches[1] };
        }
        return { type: "commit", value: content.trim() };
    }
}
exports.default = GitUrls;
//# sourceMappingURL=index.js.map