"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = __importDefault(require("../src/index"));
// test("Get current project's git online link", async () => {
//     const link = await GitUrl.getOnlineLinkAsync(path.resolve("package.json"));
//     expect(link).toMatch(/https:\/\/github.com\/.+\/git-urls\/blob\/.+\/package.json/);
// });
const remoteName = "origin";
test("Get HTTPS URL in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://github.com/build/git-urls.git",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/build/git-urls/blob/master/test/a.md");
}));
test("Get SSH URL in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "git@github.com:qinezh/git-urls",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/qinezh/git-urls/blob/master/test/a.md");
}));
test("Get HTTP URL in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "http://github.com/qinezh/git-urls.git",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("http://github.com/qinezh/git-urls/blob/master/test/a.md");
}));
test("Get HTTPS URL with username in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://qinezh@github.com/build/git-urls.git",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/build/git-urls/blob/master/test/a.md");
}));
test("Get URL with space in file path in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://qinezh@github.com/build/git-urls.git",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test space in path/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/build/git-urls/blob/master/test%20space%20in%20path/a.md");
}));
test("Get URL with section in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://qinezh@github.com/build/git-urls.git",
        ref: { type: "branch", value: "master" },
        section: {
            startLine: 2,
            endLine: 3,
            startColumn: 4,
            endColumn: 5,
        },
        relativeFilePath: "test space in path/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/build/git-urls/blob/master/test%20space%20in%20path/a.md#L2-L3");
}));
test("Get URL with special branch in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://qinezh@github.com/build/git-urls.git",
        ref: { type: "branch", value: "#test" },
        relativeFilePath: "a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/build/git-urls/blob/%23test/a.md");
}));
test("Get URL with commit SHA in GitHub", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://github.com/build/git-urls.git",
        ref: { type: "commit", value: "59f76230dd5829a10aab717265b66c6b5849365e" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/build/git-urls/blob/59f76230dd5829a10aab717265b66c6b5849365e/test/a.md");
}));
test("Get URL with basic auth", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://username:ghp_REDACTED@github.com/build/git-urls.git",
        ref: { type: "branch", value: "main" },
        relativeFilePath: "a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://github.com/build/git-urls/blob/main/a.md");
}));
//# sourceMappingURL=github.test.js.map