"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = __importDefault(require("../src/index"));
const remoteName = "origin";
test("Get HTTPS url in GitLab", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://gitlab.com/build/git-urls.git",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://gitlab.com/build/git-urls/blob/master/test/a.md");
}));
test("Get SSH URL in GitLab", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "git@gitlab.com:qinezh/git-urls",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://gitlab.com/qinezh/git-urls/blob/master/test/a.md");
}));
test("Get HTTPS url in GitLab with company name", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://gitlab.xyz.com/build/git-urls.git",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://gitlab.xyz.com/build/git-urls/blob/master/test/a.md");
}));
test("Get SSH URL in GitLab with company name", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "git@gitlab.xyz.com:qinezh/git-urls",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://gitlab.xyz.com/qinezh/git-urls/blob/master/test/a.md");
}));
test("Get URL with section in GitLab", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://qinezh@gitlab.com/build/git-urls.git",
        ref: { type: "branch", value: "master" },
        section: {
            startLine: 2,
            endLine: 3,
            startColumn: 4,
            endColumn: 5,
        },
        relativeFilePath: "a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://gitlab.com/build/git-urls/blob/master/a.md#L2-3");
}));
test("Get URL with commit SHA in GitLab", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://gitlab.com/build/git-urls.git",
        ref: { type: "commit", value: "59f76230dd5829a10aab717265b66c6b5849365e" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://gitlab.com/build/git-urls/blob/59f76230dd5829a10aab717265b66c6b5849365e/test/a.md");
}));
test("Get SSH URL with port number in GitLab", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "git@gitlab.com:1024/qinezh/git-urls",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://gitlab.com/qinezh/git-urls/blob/master/test/a.md");
}));
test("Get unsupported SSH URL", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "git@contoso.com:1024/qinezh/git-urls",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://contoso.com/qinezh/git-urls/blob/master/test/a.md");
}));
test("Get unsupported SSH URL with customized host type", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "git@contoso.com:1024/qinezh/git-urls",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/a.md",
    };
    const result = yield index_1.default.getUrl(configInfo, "GitLab");
    expect(result._unsafeUnwrap().url).toBe("https://contoso.com/qinezh/git-urls/blob/master/test/a.md");
}));
//# sourceMappingURL=gitlab.test.js.map