"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = __importDefault(require("../src/index"));
const remoteName = "origin";
test("Get file URL in VSTS", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://vsts.visualstudio.com/Collection/_git/repo",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/file",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://vsts.visualstudio.com/Collection/_git/repo?path=%2Ftest%2Ffile&version=GBmaster&_a=contents");
}));
test("Get selection block URL in VSTS", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://vsts.visualstudio.com/Collection/_git/repo",
        ref: { type: "branch", value: "master" },
        section: {
            startLine: 12,
            endLine: 23,
        },
        relativeFilePath: "test/file",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://vsts.visualstudio.com/Collection/_git/repo?path=%2Ftest%2Ffile&version=GBmaster&_a=contents&lineStyle=plain&line=12&lineEnd=23&lineStartColumn=1&lineEndColumn=1");
}));
test("Get file URL in VSTS with SSH", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "ssh://my-tenant@vs-ssh.visualstudio.com:22/Collection/_ssh/repo",
        ref: { type: "branch", value: "master" },
        relativeFilePath: "test/file",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://my-tenant.visualstudio.com/Collection/_git/repo?path=%2Ftest%2Ffile&version=GBmaster&_a=contents");
}));
test("Get selection block URL with column in VSTS", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://vsts.visualstudio.com/Collection/_git/repo",
        ref: { type: "branch", value: "master" },
        section: {
            startLine: 12,
            endLine: 23,
            startColumn: 8,
            endColumn: 9,
        },
        relativeFilePath: "test/file",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://vsts.visualstudio.com/Collection/_git/repo?path=%2Ftest%2Ffile&version=GBmaster&_a=contents&lineStyle=plain&line=12&lineEnd=23&lineStartColumn=8&lineEndColumn=9");
}));
test("Get URL with commit SHA in VSTS", () => __awaiter(void 0, void 0, void 0, function* () {
    const configInfo = {
        remoteName,
        remoteUrl: "https://vsts.visualstudio.com/Collection/_git/repo",
        ref: { type: "commit", value: "59f76230dd5829a10aab717265b66c6b5849365e" },
        relativeFilePath: "test/file",
    };
    const result = yield index_1.default.getUrl(configInfo);
    expect(result._unsafeUnwrap().url).toBe("https://vsts.visualstudio.com/Collection/_git/repo?path=%2Ftest%2Ffile&version=GC59f76230dd5829a10aab717265b66c6b5849365e&_a=contents");
}));
//# sourceMappingURL=vsts.test.js.map